from wagtail.core import hooks

from tests import views


@hooks.register('register_admin_viewset')
def register_site_chooser_viewset():
    return views.SiteChooserViewSet('site_chooser', url_prefix='site-chooser')


@hooks.register('register_admin_viewset')
def register_page_chooser_viewset():
    return views.PageChooserViewSet('page_chooser', url_prefix='page-chooser')


@hooks.register('register_admin_viewset')
def register_api_page_chooser_viewset():
    return views.APIPageChooserViewSet('api_page_chooser', url_prefix='api-page-chooser')


@hooks.register('register_admin_viewset')
def register_person_chooser_viewset():
    return views.PersonChooserViewSet('person_chooser', url_prefix='person-chooser')



import json
from urllib.parse import urlencode, urlparse
from unittest.mock import patch

from django.contrib.auth.models import User, Group
from django.test import TestCase

from wagtail.core.models import Page, Site

from .models import Person


class TestChooseView(TestCase):
    def setUp(self):
        User.objects.create_superuser(username='admin', email='admin@example.com', password='password')
        editor = User.objects.create_user(username='editor', email='editor@example.com', password='password')
        editor.groups.add(Group.objects.get(name='Editors'))

    def test_get(self):
        self.assertTrue(
            self.client.login(username='admin', password='password')
        )

        response = self.client.get('/admin/site-chooser/')
        self.assertEqual(response.status_code, 200)

        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')
        self.assertInHTML(
            '<h1 class="icon icon-site">Choose a site</h1>',
            response_json['html']
        )
        self.assertInHTML(
            '<a class="item-choice" href="/admin/site-chooser/1/">localhost [default]</a>',
            response_json['html']
        )

    def test_pagination(self):
        self.assertTrue(
            self.client.login(username='admin', password='password')
        )

        page = Page.objects.first()
        for i in range(0, 25):
            Site.objects.create(hostname='%d.example.com' % i, root_page=page)

        # fetch page 1
        response = self.client.get('/admin/site-chooser/')
        self.assertEqual(response.status_code, 200)

        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')
        self.assertInHTML(
            '<p>Page 1 of 3.</p>',
            response_json['html']
        )
        self.assertInHTML(
            '<a href="#" data-page="2" class="icon icon-arrow-right-after">Next</a>',
            response_json['html']
        )

        # fetch page 2
        response = self.client.get('/admin/site-chooser/?p=2')
        self.assertEqual(response.status_code, 200)

        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')
        self.assertInHTML(
            '<p>Page 2 of 3.</p>',
            response_json['html']
        )
        self.assertInHTML(
            '<a href="#" data-page="1" class="icon icon-arrow-left">Previous</a>',
            response_json['html']
        )
        self.assertInHTML(
            '<a href="#" data-page="3" class="icon icon-arrow-right-after">Next</a>',
            response_json['html']
        )

    def test_search(self):
        self.assertTrue(
            self.client.login(username='admin', password='password')
        )

        homepage = Page.objects.get(depth=2)
        red_page = homepage.add_child(title='A red page')
        another_red_page = homepage.add_child(title='Another red page')
        green_page = homepage.add_child(title='A green page')

        response = self.client.get('/admin/page-chooser/')
        self.assertEqual(response.status_code, 200)
        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')

        # response should include a search box
        self.assertInHTML(
            '<input type="text" name="q" placeholder="Search" required id="id_q">',
            response_json['html']
        )
        self.assertInHTML(
            '<a class="item-choice" href="/admin/page-chooser/%d/">A red page</a>' % red_page.id,
            response_json['html']
        )
        self.assertInHTML(
            '<a class="item-choice" href="/admin/page-chooser/%d/">Another red page</a>' % another_red_page.id,
            response_json['html']
        )
        self.assertInHTML(
            '<a class="item-choice" href="/admin/page-chooser/%d/">A green page</a>' % green_page.id,
            response_json['html']
        )

        response = self.client.get('/admin/page-chooser/?q=red')
        self.assertEqual(response.status_code, 200)
        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')

        # response should include red_page and another_red_page but not green_page
        self.assertInHTML(
            '<a class="item-choice" href="/admin/page-chooser/%d/">A red page</a>' % red_page.id,
            response_json['html']
        )
        self.assertInHTML(
            '<a class="item-choice" href="/admin/page-chooser/%d/">Another red page</a>' % another_red_page.id,
            response_json['html']
        )
        self.assertInHTML(
            '<a class="item-choice" href="/admin/page-chooser/%d/">A green page</a>' % green_page.id,
            response_json['html'],
            count=0
        )

    def test_creation_form(self):
        self.assertTrue(
            self.client.login(username='admin', password='password')
        )

        response = self.client.get('/admin/site-chooser/')
        self.assertEqual(response.status_code, 200)

        # Admin has create permission for sites, so should get the create form
        response_json = json.loads(response.content)
        self.assertInHTML(
            '<a href="#site-chooser-create">Create</a>',
            response_json['html']
        )
        self.assertInHTML(
            '<input type="text" name="site-chooser-create-form-hostname" maxlength="255" required id="id_site-chooser-create-form-hostname">',
            response_json['html']
        )

    def test_creation_form_requires_create_permission(self):
        self.assertTrue(
            self.client.login(username='editor', password='password')
        )

        response = self.client.get('/admin/site-chooser/')
        self.assertEqual(response.status_code, 200)

        # Editor should NOT get the create form
        response_json = json.loads(response.content)
        self.assertInHTML(
            '<a href="#site-chooser-create">Create</a>',
            response_json['html'],
            count=0
        )
        self.assertInHTML(
            '<input type="text" name="site-chooser-create-form-hostname" maxlength="255" required id="id_site-chooser-create-form-hostname">',
            response_json['html'],
            count=0
        )

        # POST should be rejected outright
        response = self.client.post('/admin/site-chooser/', {
            'site-chooser-create-form-hostname': 'foo',
            'site-chooser-create-form-port': '123',
            'site-chooser-create-form-site_name': 'foo',
            'site-chooser-create-form-root_page': Page.objects.filter(depth=2).first().pk,
        })
        self.assertEqual(response.status_code, 403)

    def test_post_invalid_creation_form(self):
        self.assertTrue(
            self.client.login(username='admin', password='password')
        )

        response = self.client.post('/admin/site-chooser/', {
            'site-chooser-create-form-hostname': '',
            'site-chooser-create-form-port': '123',
            'site-chooser-create-form-site_name': 'foo',
            'site-chooser-create-form-root_page': Page.objects.filter(depth=2).first().pk,
        })
        self.assertEqual(response.status_code, 200)
        # should be returned to the chooser view (step=choose) with a validation error
        # and the Create tab active
        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')

        self.assertInHTML(
            '<li class="active"><a href="#site-chooser-create">Create</a></li>',
            response_json['html']
        )
        self.assertInHTML(
            '<span>This field is required.</span>',
            response_json['html']
        )

    def test_post_valid_creation_form(self):
        self.assertTrue(
            self.client.login(username='admin', password='password')
        )

        response = self.client.post('/admin/site-chooser/', {
            'site-chooser-create-form-hostname': 'foo',
            'site-chooser-create-form-port': '123',
            'site-chooser-create-form-site_name': 'foo',
            'site-chooser-create-form-root_page': Page.objects.filter(depth=2).first().pk,
        })
        self.assertEqual(response.status_code, 200)

        # Site should be created
        site = Site.objects.get(hostname='foo')

        # should receive a step=chosen response
        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'chosen')
        self.assertEqual(
            response_json['result'],
            {"id": str(site.id), "string": "foo", "edit_link": "/admin/sites/%d/" % site.id}
        )


class TestChosenView(TestCase):
    def setUp(self):
        User.objects.create_superuser(username='admin', email='admin@example.com', password='password')
        self.assertTrue(
            self.client.login(username='admin', password='password')
        )

    def test_get(self):
        response = self.client.get('/admin/site-chooser/1/')
        self.assertEqual(response.status_code, 200)

        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'chosen')
        self.assertEqual(
            response_json['result'],
            {"id": "1", "string": "localhost [default]", "edit_link": "/admin/sites/1/"}
        )


class FakeResponse:
    """
    Partial mockup of the return value of requests.get
    """
    def __init__(self, text):
        self.text = text

    def json(self):
        return json.loads(self.text)


class FakeRequestsTestCase(TestCase):
    """
    a TestCase class that patches requests.get and requests.post to forward HTTP requests to the
    Django test client
    """

    def setUp(self):
        def fake_requests_get(url_string, params=None):
            url = urlparse(url_string)
            assert(url.scheme == 'http')
            assert(url.netloc == 'testserver')

            path = url.path
            if params:
                path += '?' + urlencode(params)

            response = self.client.get(path)
            return FakeResponse(response.content)

        def fake_requests_post(url_string, **kwargs):
            url = urlparse(url_string)
            assert(url.scheme == 'http')
            assert(url.netloc == 'testserver')

            if 'json' not in kwargs:
                raise Exception("non-JSON posts not supported")

            response = self.client.post(
                url.path, data=json.dumps(kwargs['json']), content_type='application/json'
            )
            return FakeResponse(response.content)

        self.requests_get_patcher = patch('requests.get', new=fake_requests_get)
        self.requests_get_patcher.start()
        self.requests_post_patcher = patch('requests.post', new=fake_requests_post)
        self.requests_post_patcher.start()

    def tearDown(self):
        self.requests_get_patcher.stop()
        self.requests_post_patcher.stop()


class TestAPIChooseView(FakeRequestsTestCase):
    def setUp(self):
        super().setUp()
        User.objects.create_superuser(username='admin', email='admin@example.com', password='password')
        self.assertTrue(
            self.client.login(username='admin', password='password')
        )

    def test_get(self):
        homepage = Page.objects.get(depth=2)
        red_page = homepage.add_child(title='A red page')

        response = self.client.get('/admin/api-page-chooser/')
        self.assertEqual(response.status_code, 200)

        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')
        self.assertInHTML(
            '<h1 class="icon icon-page">Choose a page</h1>',
            response_json['html']
        )
        self.assertInHTML(
            '<a class="item-choice" href="/admin/api-page-chooser/%d/">A red page</a>' % red_page.id,
            response_json['html']
        )

    def test_pagination(self):
        homepage = Page.objects.get(depth=2)
        for i in range(0, 25):
            homepage.add_child(title='Page %d' % i)

        # fetch page 1
        response = self.client.get('/admin/api-page-chooser/')
        self.assertEqual(response.status_code, 200)

        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')
        self.assertInHTML(
            '<p>Page 1 of 3.</p>',
            response_json['html']
        )
        self.assertInHTML(
            '<a href="#" data-page="2" class="icon icon-arrow-right-after">Next</a>',
            response_json['html']
        )

        # fetch page 2
        response = self.client.get('/admin/api-page-chooser/?p=2')
        self.assertEqual(response.status_code, 200)

        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')
        self.assertInHTML(
            '<p>Page 2 of 3.</p>',
            response_json['html']
        )
        self.assertInHTML(
            '<a href="#" data-page="1" class="icon icon-arrow-left">Previous</a>',
            response_json['html']
        )
        self.assertInHTML(
            '<a href="#" data-page="3" class="icon icon-arrow-right-after">Next</a>',
            response_json['html']
        )

    def test_search(self):
        homepage = Page.objects.get(depth=2)
        red_page = homepage.add_child(title='A red page')
        another_red_page = homepage.add_child(title='Another red page')
        green_page = homepage.add_child(title='A green page')

        response = self.client.get('/admin/api-page-chooser/')
        self.assertEqual(response.status_code, 200)
        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')

        # response should include a search box
        self.assertInHTML(
            '<input type="text" name="q" placeholder="Search" required id="id_q">',
            response_json['html']
        )
        self.assertInHTML(
            '<a class="item-choice" href="/admin/api-page-chooser/%d/">A red page</a>' % red_page.id,
            response_json['html']
        )
        self.assertInHTML(
            '<a class="item-choice" href="/admin/api-page-chooser/%d/">Another red page</a>' % another_red_page.id,
            response_json['html']
        )
        self.assertInHTML(
            '<a class="item-choice" href="/admin/api-page-chooser/%d/">A green page</a>' % green_page.id,
            response_json['html']
        )

        response = self.client.get('/admin/api-page-chooser/?q=red')
        self.assertEqual(response.status_code, 200)
        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')

        # response should include red_page and another_red_page but not green_page
        self.assertInHTML(
            '<a class="item-choice" href="/admin/api-page-chooser/%d/">A red page</a>' % red_page.id,
            response_json['html']
        )
        self.assertInHTML(
            '<a class="item-choice" href="/admin/api-page-chooser/%d/">Another red page</a>' % another_red_page.id,
            response_json['html']
        )
        self.assertInHTML(
            '<a class="item-choice" href="/admin/api-page-chooser/%d/">A green page</a>' % green_page.id,
            response_json['html'],
            count=0
        )


class TestAPIChosenView(FakeRequestsTestCase):
    def setUp(self):
        super().setUp()
        User.objects.create_superuser(username='admin', email='admin@example.com', password='password')
        self.assertTrue(
            self.client.login(username='admin', password='password')
        )

    def test_get(self):
        response = self.client.get('/admin/api-page-chooser/2/')
        self.assertEqual(response.status_code, 200)

        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'chosen')
        self.assertEqual(
            response_json['result'],
            {"id": "2", "string": "Welcome to your new Wagtail site!", "edit_link": "/admin/pages/2/edit/"}
        )


class TestAPICreateForm(FakeRequestsTestCase):
    def setUp(self):
        super().setUp()
        User.objects.create_superuser(username='admin', email='admin@example.com', password='password')
        self.assertTrue(
            self.client.login(username='admin', password='password')
        )

    def test_get(self):
        response = self.client.get('/admin/person-chooser/')
        self.assertEqual(response.status_code, 200)
        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')

        # Create form should be displayed
        response_json = json.loads(response.content)
        self.assertInHTML(
            '<a href="#person-chooser-create">Create</a>',
            response_json['html']
        )
        self.assertInHTML(
            '<input type="text" name="person-chooser-create-form-first_name" required id="id_person-chooser-create-form-first_name">',
            response_json['html']
        )

    def test_post_invalid(self):
        response = self.client.post('/admin/person-chooser/', {
            'person-chooser-create-form-first_name': 'Bob',
            'person-chooser-create-form-last_name': '',
            'person-chooser-create-form-job_title': 'Builder',
        })
        self.assertEqual(response.status_code, 200)

        # should be returned to the chooser view (step=choose) with a validation error
        # and the Create tab active
        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'choose')

        self.assertInHTML(
            '<li class="active"><a href="#person-chooser-create">Create</a></li>',
            response_json['html']
        )
        self.assertInHTML(
            '<span>This field is required.</span>',
            response_json['html']
        )

    def test_post_valid(self):
        response = self.client.post('/admin/person-chooser/', {
            'person-chooser-create-form-first_name': 'Gordon',
            'person-chooser-create-form-last_name': 'Ramsay',
            'person-chooser-create-form-job_title': 'Chef',
        })
        self.assertEqual(response.status_code, 200)

        # Person should be created
        person = Person.objects.get(first_name='Gordon')

        # should receive a step=chosen response
        response_json = json.loads(response.content)
        self.assertEqual(response_json['step'], 'chosen')
        self.assertEqual(
            response_json['result'],
            {"id": str(person.id), "string": "Gordon Ramsay", "edit_link": None}
        )



from __future__ import absolute_import, unicode_literals

import os

DATABASES = {
    'default': {
        'ENGINE': os.environ.get('DATABASE_ENGINE', 'django.db.backends.sqlite3'),
        'NAME': os.environ.get('DATABASE_NAME', 'wagtail_generic_chooser'),
        'USER': os.environ.get('DATABASE_USER', None),
        'PASSWORD': os.environ.get('DATABASE_PASS', None),
        'HOST': os.environ.get('DATABASE_HOST', None),

        'TEST': {
            'NAME': os.environ.get('DATABASE_NAME', None),
        }
    }
}


SECRET_KEY = 'not needed'

ROOT_URLCONF = 'tests.urls'

STATIC_URL = '/static/'

STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
)

USE_TZ = True

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                'django.template.context_processors.request',
            ],
            'debug': True,
        },
    },
]

MIDDLEWARE = [
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'wagtail.core.middleware.SiteMiddleware',
]

INSTALLED_APPS = (
    'generic_chooser',
    'tests',

    'wagtail.api.v2',
    'wagtail.search',
    'wagtail.sites',
    'wagtail.users',
    'wagtail.images',
    'wagtail.documents',
    'wagtail.admin',
    'wagtail.core',

    'taggit',

    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
)

PASSWORD_HASHERS = (
    'django.contrib.auth.hashers.MD5PasswordHasher',  # don't use the intentionally slow default password hasher
)

WAGTAIL_SITE_NAME = 'wagtail-generic-chooser test'

REST_FRAMEWORK = {
    'DEFAULT_PERMISSION_CLASSES': [
        'rest_framework.permissions.AllowAny'
    ],

    'DEFAULT_PAGINATION_CLASS': 'wagtail.api.v2.pagination.WagtailPagination',
    'PAGE_SIZE': 100,
}



# Generated by Django 2.2 on 2019-06-13 15:46

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Person',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('first_name', models.CharField(max_length=255, verbose_name='First name')),
                ('last_name', models.CharField(max_length=255, verbose_name='Last name')),
                ('job_title', models.CharField(max_length=255, verbose_name='Job title')),
            ],
        ),
    ]



from wagtail.api.v2.endpoints import PagesAPIEndpoint
from wagtail.api.v2.router import WagtailAPIRouter

api_router = WagtailAPIRouter('wagtailapi')

api_router.register_endpoint('pages', PagesAPIEndpoint)



import json

from django.contrib.admin.utils import quote
from django.core.exceptions import ObjectDoesNotExist
from django.forms import widgets
from django.template.loader import render_to_string
from django.urls import reverse
from django.utils.translation import ugettext_lazy as _

import requests

from wagtail.utils.widgets import WidgetWithScript


class AdminChooser(WidgetWithScript, widgets.Input):
    input_type = 'hidden'
    choose_one_text = _("Choose an item")
    choose_another_text = _("Choose another item")
    clear_choice_text = _("Clear choice")
    link_to_chosen_text = _("Edit this item")
    show_edit_link = True
    classname = None  # CSS class for the top-level element

    model = None

    # URL route name for editing an existing item - should return the URL of the item's edit view
    # when reversed with the item's quoted PK as its only argument. If no suitable URL route exists
    # (e.g. it requires additional arguments), subclasses can override get_edit_item_url instead.
    edit_item_url_name = None

    # URL route name for the chooser modal view - should return the URL of the chooser view when
    # reversed with no arguments. If no suitable URL route exists, subclasses can override
    # get_choose_modal_url instead.
    # This will appear as the attribute data-choose-modal-url on the top-level element of the
    # chooser widget.
    choose_modal_url_name = None

    template = "generic_chooser/widgets/chooser.html"

    # when looping over form fields, this one should appear in visible_fields, not hidden_fields
    # despite the underlying input being type="hidden"
    is_hidden = False

    def get_instance(self, value):
        return self.model.objects.get(pk=value)

    def get_edit_item_url(self, instance):
        if self.edit_item_url_name is None:
            return None
        else:
            return reverse(self.edit_item_url_name, args=(quote(instance.pk),))

    def get_choose_modal_url(self):
        if self.choose_modal_url_name is None:
            return None
        else:
            return reverse(self.choose_modal_url_name)

    def value_from_datadict(self, data, files, name):
        # treat the empty string as None
        result = super().value_from_datadict(data, files, name)
        if result == '':
            return None
        else:
            return result

    def get_title(self, instance):
        return str(instance)

    def render_html(self, name, value, attrs):
        if value is None:
            instance = None
        else:
            try:
                instance = self.get_instance(value)
            except (ObjectDoesNotExist if self.model is None else self.model.DoesNotExist):
                value = None
                instance = None

        original_field_html = super().render_html(name, value, attrs)

        if instance is None:
            edit_item_url = None
        else:
            edit_item_url = self.get_edit_item_url(instance)

        return render_to_string(self.template, {
            'widget': self,
            'original_field_html': original_field_html,
            'attrs': attrs,
            'value': value,
            'item': instance,
            'title': '' if instance is None else self.get_title(instance),
            'edit_item_url': edit_item_url,
            'choose_modal_url': self.get_choose_modal_url(),
        })

    def render_js_init(self, id_, name, value):
        return "createChooserWidget({0});".format(json.dumps(id_))

    def __init__(self, **kwargs):
        # allow choose_one_text / choose_another_text to be overridden per-instance
        if 'choose_one_text' in kwargs:
            self.choose_one_text = kwargs.pop('choose_one_text')
        if 'choose_another_text' in kwargs:
            self.choose_another_text = kwargs.pop('choose_another_text')
        if 'clear_choice_text' in kwargs:
            self.clear_choice_text = kwargs.pop('clear_choice_text')
        if 'link_to_chosen_text' in kwargs:
            self.link_to_chosen_text = kwargs.pop('link_to_chosen_text')
        if 'show_edit_link' in kwargs:
            self.show_edit_link = kwargs.pop('show_edit_link')
        super().__init__(**kwargs)

    class Media:
        js = [
            'generic_chooser/js/chooser-modal.js',
            'generic_chooser/js/chooser-widget.js',
        ]


class DRFChooser(AdminChooser):
    """A chooser widget associated with a Django REST Framework API endpoint"""
    def get_instance(self, id):
        url = '%s%s/?format=json' % (self.api_base_url, quote(id))
        result = requests.get(url).json()

        if 'id' not in result:
            # assume this is a 'not found' report
            raise ObjectDoesNotExist(result['message'])

        return result

    def get_edit_item_url(self, instance):
        if self.edit_item_url_name is None:
            return None
        else:
            return reverse(self.edit_item_url_name, args=(instance['id'],))



from django.conf.urls import include, url
from rest_framework import routers, serializers, viewsets
from wagtail.admin import urls as wagtailadmin_urls
from wagtail.core import urls as wagtail_urls

from .api import api_router as wagtail_api_router
from .models import Person


class PersonSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = Person
        fields = ('id', 'first_name', 'last_name', 'job_title')


class PersonViewSet(viewsets.ModelViewSet):
    queryset = Person.objects.all()
    serializer_class = PersonSerializer

# Register a writeable API for the Person model at /person-api,
# separate from the Wagtail API
router = routers.DefaultRouter()
router.register(r'person-api', PersonViewSet)

urlpatterns = [
    url(r'^admin/', include(wagtailadmin_urls)),
    url(r'^api/v2/', wagtail_api_router.urls),

    # Wire up our API using automatic URL routing.
    url(r'^', include(router.urls)),

    url(r'', include(wagtail_urls)),
]



from django import forms
from wagtail.core.models import Page, Site
from generic_chooser.views import DRFChooserMixin, DRFChooserViewSet, ModelChooserViewSet


class SiteChooserViewSet(ModelChooserViewSet):
    model = Site
    icon = 'site'
    page_title = "Choose a site"
    per_page = 10
    edit_item_url_name = 'wagtailsites:edit'
    order_by = 'hostname'
    fields = ['hostname', 'port', 'site_name', 'root_page', 'is_default_site']


class PageChooserViewSet(ModelChooserViewSet):
    model = Page
    icon = 'page'
    page_title = "Choose a page"
    edit_item_url_name = 'wagtailadmin_pages:edit'


class APIPageChooserViewSet(DRFChooserViewSet):
    icon = 'page'
    page_title = "Choose a page"
    title_field_name = 'title'
    api_base_url = 'http://testserver/api/v2/pages/'
    edit_item_url_name = 'wagtailadmin_pages:edit'

    # enables the search box and passes search terms to the API as the 'search' query parameter
    is_searchable = True

    per_page = 10


class PersonChooserMixin(DRFChooserMixin):
    def get_object_string(self, item):
        return "%s %s" % (item['first_name'], item['last_name'])


class PersonForm(forms.Form):
    first_name = forms.CharField(required=True)
    last_name = forms.CharField(required=True)
    job_title = forms.CharField(required=True)


class PersonChooserViewSet(DRFChooserViewSet):
    icon = 'user'
    api_base_url = 'http://testserver/person-api/'
    form_class = PersonForm
    chooser_mixin_class = PersonChooserMixin
    prefix = 'person-chooser'



from django.db import models


class Person(models.Model):
    first_name = models.CharField("First name", max_length=255)
    last_name = models.CharField("Last name", max_length=255)
    job_title = models.CharField("Job title", max_length=255)
